@@ -177,7 +177,7 @@ class BaseField(dict):
         try:
             return super(BaseField, self).__getattribute__(item)
         except:
-            return self.get(item)
+            return super(BaseField, self).get(item)
 
     def __call__(self):
         return self
