@@ -63,33 +63,34 @@ def json_dump(data):
     return json.dumps(data, cls=JsonDecoder)
 
 
+class BaseData(dict):
+    """ result obj """
+
+    def __init__(self, *args, **kwargs):
+        super(self.__class__, self).__init__(*args, **kwargs)
+
+    def __add__(self, other):
+        assert isinstance(other, dict)
+        for k, v in other.items():
+            self.__setitem__(k, v)
+        return self
+
+    def __setitem__(self, key, value):
+        if isinstance(value, dict):
+            super(self.__class__, self).__setitem__(key, self.__class__(**value))
+        else:
+            super(self.__class__, self).__setitem__(key, value)
+
+    def __getattribute__(self, item):
+        try:
+            return super(self.__class__, self).__getattribute__(item)
+        except:
+            return super(self.__class__, self).get(item)
+
+
 class Result(object):
     """ es result obj """
 
-    class Data(dict):
-        """ result obj """
-
-        def __init__(self, *args, **kwargs):
-            super(self.__class__, self).__init__(*args, **kwargs)
-
-        def __add__(self, other):
-            assert isinstance(other, dict)
-            for k, v in other.items():
-                self.__setitem__(k, v)
-            return self
-
-        def __setitem__(self, key, value):
-            if isinstance(value, dict):
-                super(self.__class__, self).__setitem__(key, self.__class__(**value))
-            else:
-                super(self.__class__, self).__setitem__(key, value)
-
-        def __getattribute__(self, item):
-            try:
-                return super(self.__class__, self).__getattribute__(item)
-            except:
-                return super(self.__class__, self).get(item)
-
     def __init__(self, result: dict):
         self.result: dict = result
 
@@ -106,4 +107,4 @@ class Result(object):
     def __iter__(self):
         """ 遍历结果 """
         for item in self.hits():
-            yield self.Data(source_id=item["_id"], **item['_source'])
+            yield BaseData(source_id=item["_id"], **item['_source'])
